:root {
    --color: rgba(192, 198, 212, 1);
    --backgroundColor: #242424;
}

body {
    color: rgba(192, 198, 212, 1) !important;
    background-color: #242424 !important;
}

u {
    border-bottom: 1px solid rgba(192, 198, 212, 1) !important;
}

strike {
    text-decoration-color: rgba(192, 198, 212, 1) !important;
}

strike[style="text-decoration-line: underline;"] {
    border-bottom: 1px solid rgba(192, 198, 212, 1) !important;
}

.title,
.time {
    color: rgba(192, 198, 212, 1) !important
}

.li {
    background: rgba(255, 255, 255, 0.05)
}

.minute {
    color: rgba(109, 124, 136, 1) !important
}

.note-popover .popover-content {
    background: rgba(42, 42, 42, 1) !important
}

.tooltip-inner {
    color: rgba(192, 198, 212, 1);
    background-color: rgba(42, 42, 42, 1) !important;
    border: 1px solid rgba(0, 0, 0, 0.30);
}

.btn-default {
    color: rgba(197, 207, 224, 1) !important
}

.dropdown-menu {
    background: rgba(42, 42, 42, 0.98) !important
}

.colorFont {
    color: rgba(192, 198, 212, 1) !important
}

.dropdown-fontsize li a {
    color: rgba(192, 198, 212, 1) !important
}

.dropdown-fontname li a {
    color: rgba(192, 198, 212, 1) !important
}

.dropdown-fontsize>li>a,
.dropdown-fontname>li>a {
    color: rgba(197, 207, 224, 1)
}

.icon-forecolor .path1 {
    color: rgba(192, 198, 212, 1);
}

.icon-backcolor .path2 {
    color: rgb(255, 255, 255, .2);
}

.icon-forecolor .path2 {
    color: rgb(255, 255, 255, .2);
}

.note-editor .note-toolbar>.note-btn-group,
.note-popover .popover-content>.note-line {
    background-color: rgba(255, 255, 255, 0.1);
}

.note-popover .popover-content .note-color-palette div .note-color-btn {
    border-color: rgba(255, 255, 255, 0.2);
}

.note-color-back .note-color-palette .note-color-row:first-child .note-color-btn:first-child::before {
    background-color: rgba(255, 255, 255, 0.2);;
}

.planButton button {
    background: rgba(255, 255, 255, 0.10);
}

.btn-default:hover {
    background-color: rgba(255, 255, 255, 0.05) !important;
}

body::-webkit-scrollbar-thumb:hover,
.dropdown-fontname::-webkit-scrollbar-thumb:hover {
    background-color: rgba(255, 255, 255, .25);
    border-color: rgba(0, 0, 0, 0.1);
}

body::-webkit-scrollbar-thumb:active,
.dropdown-fontname::-webkit-scrollbar-thumb:active {
    background-color: rgba(255, 255, 255, .3);
    border-color: rgba(0, 0, 0, 0.1);
}

.translate>div {
    color: rgba(192, 198, 212, 1) !important;
}

.fontsizeBut .note-current-fontsize {
    color: rgba(255, 255, 255, 1);
}

.fontnameBut .note-current-fontname {
    color: rgba(255, 255, 255, 1);
}

/********** 悬浮语言播放控件 **********/
.airVoicePlaybackContainer .voicePlayback {    
    background: #171623 !important;
    border: 1px solid rgb(255, 255, 255, 0.05);
    outline: 1px solid rgb(0, 0, 0, 0.6);
    box-shadow: 0px 4px 8px rgba(0, 0, 0, 0.1);
}

/* .voicePlayback {
    background: #ffffff19 !important;
} */

.voicePlayback .voiceBtn {
    background-image: url('../img/audio_file_play/Normal/Dark.svg');
}

.voicePlayback .voiceBtn:hover {
    background-image: url('../img/audio_file_play/Hover/Dark.svg');
}

.voicePlayback .voiceBtn:active {
    background-image: url('../img/audio_file_play/Pressed/Dark.svg');
}
